# Import imzMLParser from pyimzml package
from pyimzml.ImzMLParser import ImzMLParser
# Import numpy package
import numpy as np
# Import numpy package
import matplotlib.pyplot as plt
# Import Formula module from molmass package for formula-mass conversion
from molmass import Formula

def xic_funct_tol(formula, tol_ppm, mzs, intensities):
    target = Formula(formula).isotope.mass
    tol_da = target*tol_ppm/1000000
    massmin = target - tol_da
    massmax = target + tol_da
    xic = sum(intensities[(mzs>massmin)&(mzs<massmax)])
    return xic

# Create the MSI data reader
data = ImzMLParser("Data/MSIData.imzML")
xmax= data.imzmldict["max count of pixels x"]
ymax = data.imzmldict["max count of pixels y"]
formula = "C47H75NO8H"
tol_ppm = 5

xs, ys, values = [], [], []
for idx, (x,y,z) in enumerate(data.coordinates):
    mzs, intensities = data.getspectrum(idx)
    value = xic_funct_tol(formula, tol_ppm, mzs, intensities)
    xs.append(x)
    ys.append(y)
    values.append(value)

values_array = np.zeros((ymax+1, xmax+1))
values_array[ys, xs] = values

plt.imshow(values_array)
plt.show()

