# Import imzMLParser from pyimzml package
from pyimzml.ImzMLParser import ImzMLParser
# Import numpy package
import numpy as np
# Import numpy package
import matplotlib.pyplot as plt
# Import Formula module from molmass package for formula-mass conversion
from molmass import Formula

def xic_funct_tol(formula, tol_ppm, mzs, intensities):
    target = Formula(formula).isotope.mass
    tol_da = target*tol_ppm/1000000
    massmin = target - tol_da
    massmax = target + tol_da
    xic = sum(intensities[(mzs>massmin)&(mzs<massmax)])
    return xic

# Create the MSI data reader
data = ImzMLParser("Data/MSIData.imzML")
xmax= data.imzmldict["max count of pixels x"]
ymax = data.imzmldict["max count of pixels y"]
with open("Targets.txt") as f:
    formulas = f.read().split("\n")
adducts = ["H", "Na", "K", "NH4"]
tol_ppm = 5

targets = [f+a for a in adducts for f in formulas]
data_dict = dict(zip(targets,[np.zeros((ymax+1,xmax+1))for t in targets]))

for idx, (x,y,z) in enumerate(data.coordinates):
    mzs, intensities = data.getspectrum(idx)
    for f in targets:
        z = xic_funct_tol(f, tol_ppm, mzs, intensities)
        data_dict[f][(y,x)] = z

for i, d in enumerate(data_dict.values()):
    plt.imshow(d)
    plt.savefig(targets[i]+".png")
