from pyimzml.ImzMLParser import ImzMLParser
import numpy as np
import matplotlib.pyplot as plt
from molmass import Formula

def func(f, tol_ppm, mzs, intensities):
    target = Formula(f).isotope.mass
    tol_da = target*tol_ppm/1000000
    massmin = target - tol_da
    massmax = target + tol_da
    xic = sum(intensities[(mzs>massmin)&(mzs<massmax)])
    xic_norm = xic/sum(intensities)
    return xic_norm

data = ImzMLParser("Data/MSIData.imzML")
xmax = data.imzmldict["max count of pixels x"]
ymax = data.imzmldict["max count of pixels y"]
formula = "C47H75NO8"
adducts = ["H", "Na", "K", "NH4"]
tol_ppm = 5


for a in adducts:
    form_a = formula + a
    tics = []
    xs = []
    ys = []
    for i,(x,y,z) in enumerate(data.coordinates):
        mzs, ints = data.getspectrum(i)
        tic = func(form_a, tol_ppm, mzs, ints)
        tics.append(tic)
        xs.append(x)
        ys.append(y)


    values_array = np.zeros((ymax+1, xmax+1))
    values_array[ys, xs] = tics

    plt.imshow(values_array)
    plt.savefig(formula+a+".png")

    
    


